#include <math.h>
#include <iostream>
#include <vector>
#include <string>
#include "svg.h"
#include <algorithm>

using namespace std;

void svg_begin(double width, double height)
{
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void svg_end()
{
    cout << "</svg>\n";
}

void svg_text(double left, double baseline, string text)
{
    cout << "<text x='" << left << "' y='" << baseline << "'>" << text << "</text>";
}

void svg_rect(double x, double y, double width, double height, string stroke = "black", string fill = "black")
{
    cout << "<rect x='"<<x<<"' y='"<<y<<"' width='"<<width<<"' height='"<<height<<"' stroke='"<<stroke<<"' fill='"<<fill<<"' />";

}

void show_histogram_svg(const vector<size_t>& bins, size_t bin_height)
{
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 700;//
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = 10;
    const auto BLACK = "black";
    const auto RED = "red";
    const auto MAX_WIDTH = IMAGE_WIDTH-TEXT_WIDTH;

    if (!bins.empty()){
        const size_t total_height = bins.size() * bin_height;
        if (total_height > IMAGE_HEIGHT) {
            bin_height = IMAGE_HEIGHT / bins.size();
        }
    }

    svg_begin(IMAGE_WIDTH,IMAGE_HEIGHT);

       double top = 0;
    if (!bins.empty()) {
        double max_count = *max_element(bins.begin(), bins.end());

        for (size_t bin : bins) {
            double bin_width = MAX_WIDTH * (static_cast<double>(bin) / max_count);
            svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
            svg_rect(TEXT_WIDTH, top, bin_width, bin_height, BLACK, RED); // 
            top += bin_height; // 
        }
    }

    svg_end();
}


